ItemSeparatorBuilder<SECTION, ITEM> typedef

ItemSeparatorBuilder<SECTION, ITEM> = Widget? Function(BuildContext context, SECTION section, ITEM? item, int sectionIndex, int? itemIndex, {required bool insideSection})

Build separator widget used in ListViewWithDataSource, witch will display after the item. If insideSection is true, the widget displayed in between item views. If insideSection is false, the widget displayed in between header and item or between item and footer. When item is null and insideSection is false, the widget displayed between header and first item. If not needed, return null.

Implementation

typedef ItemSeparatorBuilder<SECTION, ITEM> = Widget? Function(
  BuildContext context,
  SECTION section,
  ITEM? item,
  int sectionIndex,
  int? itemIndex, {
  required bool insideSection,
});