ListViewDataSource<SECTION, ITEM> class
DataSource for ListViewWithDataSource. Hold display items for each section groups.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- listItemCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
SECTION> -
no setter
Methods
-
addSection(
SECTION section) → void - Add section to the end of the list, if not exists. If already exists, do nothing.
-
appendItem(
SECTION section, ITEM item) → void - Add item to the end of the section's item list. If section not exists, create new section. If section already exists, same section will be merged.
-
appendItems(
SECTION section, List< ITEM> items) → void - Add items to the end of the section's item list. If section not exists, create new section. If section already exists, same section will be merged.
-
metaItem(
int index) → ListViewDataSourceItemType< SECTION, ITEM> -
nextMetaItem(
int index) → ListViewDataSourceItemType< SECTION, ITEM> ? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sectionItems(
SECTION section) → List< ITEM> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited